# eric7.Preferences.ConfigurationPages.ShellPage

Module implementing the Shell configuration page.

### Global Attributes

None

### Classes

ShellPage | Class implementing the Shell configuration page.

### Functions

create | Module function to create the configuration page.

## ShellPage

Class implementing the Shell configuration page.

### Derived from

ConfigurationPageBase, Ui_ShellPage

### Class Attributes

None

### Class Methods

None

### Methods

ShellPage | Constructor
on_linenumbersFontButton_clicked | Private method used to select the font for the editor margins.
on_monospacedFontButton_clicked | Private method used to select the font to be used as the monospaced font.
polishPage | Public slot to perform some polishing actions.
save | Public slot to save the Shell configuration.

### Static Methods

None

#### ShellPage (Constructor)

ShellPage()

Constructor

#### ShellPage.on_linenumbersFontButton_clicked

on_linenumbersFontButton_clicked()

Private method used to select the font for the editor margins.

#### ShellPage.on_monospacedFontButton_clicked

on_monospacedFontButton_clicked()

Private method used to select the font to be used as the monospaced font.

#### ShellPage.polishPage

polishPage()

Public slot to perform some polishing actions.

#### ShellPage.save

save()

Public slot to save the Shell configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up